// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
'use strict';
var phosphor_widget_1 = require('phosphor-widget');
/**
 * The landing page extension.
 */
exports.landingExtension = {
    id: 'jupyter.extensions.landing',
    activate: activateLanding
};
function activateLanding(app) {
    var widget = new phosphor_widget_1.Widget();
    widget.id = 'landing-jupyterlab';
    widget.title.text = 'JupyterLab';
    widget.title.closable = true;
    widget.addClass('jp-Landing');
    var dialog = document.createElement('div');
    dialog.className = 'jp-Landing-dialog';
    widget.node.appendChild(dialog);
    var title = document.createElement('span');
    title.textContent = 'Welcome to';
    title.className = 'jp-Landing-title';
    dialog.appendChild(title);
    var logo = document.createElement('span');
    logo.className = 'jp-Landing-logo';
    dialog.appendChild(logo);
    var header = document.createElement('span');
    header.textContent = 'Start a new activity:';
    header.className = 'jp-Landing-header';
    dialog.appendChild(header);
    var body = document.createElement('div');
    body.className = 'jp-Landing-body';
    dialog.appendChild(body);
    for (var _i = 0, _a = ['Notebook', 'Terminal', 'Text Editor']; _i < _a.length; _i++) {
        var name_1 = _a[_i];
        var column = document.createElement('div');
        body.appendChild(column);
        column.className = 'jp-Landing-column';
        var img_1 = document.createElement('span');
        var imgName = name_1.replace(' ', '');
        img_1.className = "jp-Landing-image" + imgName + " jp-Landing-image";
        column.appendChild(img_1);
        var text = document.createElement('span');
        text.textContent = name_1;
        text.className = 'jp-Landing-text';
        column.appendChild(text);
    }
    var img = body.getElementsByClassName('jp-Landing-imageNotebook')[0];
    img.addEventListener('click', function () {
        app.commands.execute('file-operations:new-notebook');
    });
    img = body.getElementsByClassName('jp-Landing-imageTextEditor')[0];
    img.addEventListener('click', function () {
        app.commands.execute('file-operations:new-text-file');
    });
    img = body.getElementsByClassName('jp-Landing-imageTerminal')[0];
    img.addEventListener('click', function () {
        app.commands.execute('terminal:create-new');
    });
    app.commands.add([{
            id: 'jupyterlab-launcher:show',
            handler: function () {
                if (!widget.isAttached) {
                    app.shell.addToMainArea(widget);
                }
                app.shell.activateMain(widget.id);
            }
        }]);
    app.palette.add([{
            command: 'jupyterlab-launcher:show',
            text: 'JupyterLab Launcher',
            category: 'Help'
        }]);
    app.shell.addToMainArea(widget);
}
