import { NotebookPanel } from 'jupyter-js-notebook';
import { DocumentRegistry } from 'jupyter-js-ui/lib/docmanager';
import { RenderMime } from 'jupyter-js-ui/lib/rendermime';
import { Application } from 'phosphide/lib/core/application';
import { MimeData as IClipboard } from 'phosphor-dragdrop';
import { ISignal } from 'phosphor-signaling';
import { Widget } from 'phosphor-widget';
import { JupyterServices } from '../services/plugin';
/**
 * The notebook file handler provider.
 */
export declare const notebookHandlerExtension: {
    id: string;
    requires: (typeof DocumentRegistry | typeof JupyterServices | typeof RenderMime | typeof IClipboard)[];
    activate: (app: Application, registry: DocumentRegistry, services: JupyterServices, rendermime: RenderMime<Widget>, clipboard: IClipboard) => Promise<void>;
};
/**
 * An interface exposing the current active notebook.
 */
export declare class ActiveNotebook {
    /**
     * Construct a new active notebook tracker.
     */
    constructor();
    /**
     * A signal emitted when the active notebook changes.
     */
    activeNotebookChanged: ISignal<ActiveNotebook, NotebookPanel>;
    /**
     * The current active notebook.
     */
    activeNotebook: NotebookPanel;
    private _activeWidget;
    private _widgets;
}
/**
 * A service tracking the active notebook widget.
 */
export declare const activeNotebookProvider: {
    id: string;
    provides: typeof ActiveNotebook;
    resolve: () => ActiveNotebook;
};
