import { IKernelManager, INotebookSessionManager, IContentsManager, IKernelSpecIds, IAjaxSettings } from 'jupyter-js-services';
/**
 * An implementation of a services provider.
 */
export declare class JupyterServices {
    /**
     * Construct a new services provider.
     */
    constructor(baseUrl: string, ajaxSettings: IAjaxSettings, specs: IKernelSpecIds);
    /**
     * Get kernel specs.
     */
    kernelspecs: IKernelSpecIds;
    /**
     * Get kernel manager instance.
     *
     * #### Notes
     * This is a read-only property.
     */
    kernelManager: IKernelManager;
    /**
     * Get the session manager instance.
     *
     * #### Notes
     * This is a read-only property.
     */
    notebookSessionManager: INotebookSessionManager;
    /**
     * Get the contents manager instance.
     *
     * #### Notes
     * This is a read-only property.
     */
    contentsManager: IContentsManager;
    private _kernelManager;
    private _sessionManager;
    private _contentsManager;
    private _kernelspecs;
}
/**
 * The default services provider.
 */
export declare const servicesProvider: {
    id: string;
    provides: typeof JupyterServices;
    resolve: () => Promise<JupyterServices>;
};
