// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
'use strict';
var jupyter_js_utils_1 = require('jupyter-js-utils');
var jupyter_js_services_1 = require('jupyter-js-services');
/**
 * An implementation of a services provider.
 */
var JupyterServices = (function () {
    /**
     * Construct a new services provider.
     */
    function JupyterServices(baseUrl, ajaxSettings, specs) {
        this._kernelManager = null;
        this._sessionManager = null;
        this._contentsManager = null;
        this._kernelspecs = null;
        var options = { baseUrl: baseUrl, ajaxSettings: ajaxSettings };
        this._kernelspecs = specs;
        this._kernelManager = new jupyter_js_services_1.KernelManager(options);
        this._sessionManager = new jupyter_js_services_1.NotebookSessionManager(options);
        this._contentsManager = new jupyter_js_services_1.ContentsManager(baseUrl, ajaxSettings);
    }
    Object.defineProperty(JupyterServices.prototype, "kernelspecs", {
        /**
         * Get kernel specs.
         */
        get: function () {
            return this._kernelspecs;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(JupyterServices.prototype, "kernelManager", {
        /**
         * Get kernel manager instance.
         *
         * #### Notes
         * This is a read-only property.
         */
        get: function () {
            return this._kernelManager;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(JupyterServices.prototype, "notebookSessionManager", {
        /**
         * Get the session manager instance.
         *
         * #### Notes
         * This is a read-only property.
         */
        get: function () {
            return this._sessionManager;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(JupyterServices.prototype, "contentsManager", {
        /**
         * Get the contents manager instance.
         *
         * #### Notes
         * This is a read-only property.
         */
        get: function () {
            return this._contentsManager;
        },
        enumerable: true,
        configurable: true
    });
    return JupyterServices;
}());
exports.JupyterServices = JupyterServices;
/**
 * The default services provider.
 */
exports.servicesProvider = {
    id: 'jupyter.services.services',
    provides: JupyterServices,
    resolve: function () {
        var baseUrl = jupyter_js_utils_1.getBaseUrl();
        var ajaxSettings = jupyter_js_utils_1.getConfigOption('ajaxSettings');
        var options = { baseUrl: baseUrl, ajaxSettings: ajaxSettings };
        return jupyter_js_services_1.getKernelSpecs(options).then(function (specs) {
            return new JupyterServices(baseUrl, ajaxSettings, specs);
        });
    }
};
