// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
"use strict";
var docmanager_1 = require('jupyter-js-ui/lib/docmanager');
var phosphor_disposable_1 = require('phosphor-disposable');
var widgets_1 = require('jupyter-js-ui/lib/widgets');
var WIDGET_MIMETYPE = 'application/vnd.jupyter.widget';
/**
 * The widget manager provider.
 */
exports.widgetManagerExtension = {
    id: 'jupyter.extensions.widgetManager',
    requires: [docmanager_1.DocumentRegistry],
    activate: activateWidgetExtension
};
var IPyWidgetExtension = (function () {
    function IPyWidgetExtension() {
    }
    /**
     * Create a new extension object.
     */
    IPyWidgetExtension.prototype.createNew = function (nb, model, context) {
        var wManager = new widgets_1.WidgetManager(context);
        var wRenderer = new widgets_1.WidgetRenderer(wManager);
        nb.content.rendermime.addRenderer(WIDGET_MIMETYPE, wRenderer, 0);
        return new phosphor_disposable_1.DisposableDelegate(function () {
            nb.content.rendermime.removeRenderer(WIDGET_MIMETYPE);
            wRenderer.dispose();
            wManager.dispose();
        });
    };
    return IPyWidgetExtension;
}());
exports.IPyWidgetExtension = IPyWidgetExtension;
/**
 * Activate the widget extension.
 */
function activateWidgetExtension(app, registry) {
    registry.registerExtension('Notebook', new IPyWidgetExtension());
}
